drop _all
*generate 1000 observations
set obs 999

*draw a sample of binary x (succes prob=0.7)
gen x=uniform()>0.3 if _n<=1000

*create a grid of possible pi values from 0.001 to 0.999 with step 0.001
gen pi=_n/1000

*lden will hold the log likelihood (probability function) contribution of each observation x for a given pi
gen double lden=.

*will hold the sum of log likelihood (pf) contributions from 100 observations for the corresponding pi
gen double Slden=.


*treat it as one binomial trial instead of N bernouli trials
*****************
count if !mi(x)
local denom=r(N)
count if x==1
local nom=r(N)
gen double Slden2=.
*****************

*repeat for all values of mu
forval i=1(1)1000 {
	*normal den gives the pdf
	qui replace lden=log(pi[`i']^x*(1-pi[`i'])^(1-x))
	*first summarize to get the sum which is stored in r(sum)
	qui sum lden
	*replace Slden for given mu (only in line i)
	qui replace Slden=r(sum) if _n==`i'
	
	*one binomial approach
	qui replace Slden2=log(comb(`denom',`nom'))+`nom'*log(pi[`i'])+(`denom'-`nom')*log(1-pi[`i']) if _n==`i'
}

*a null glm model for x (logit link)
glm x,link(logit)

*coincides with aritmetic mean
sum x

* or proportion of 1's
tab x

*graph of log-likelihood vs pi
sc Slden pi

*check which pi value from the grid maximizes log-likelihood 
gsort -Slden
li in 1

*graph of two log-likelihoods vs pi
sc Slden Slden2 pi

